 #include <Wire.h>
#include <RTClib.h>

RTC_DS1307 rtc;

void setup() {
  Serial.begin(9600);

  // Check if the RTC is connected
  if (!rtc.begin()) {
    Serial.println("Couldn't find RTC");
    while (1);
  }

  // Check if the RTC is NOT running, which means the time needs to be set
  if (!rtc.isrunning()) {
    Serial.println("RTC is NOT running, setting the time!");

    // Set the date and time only once:
    rtc.adjust(DateTime(2024, 10, 6, 11, 29, 0)); // Set to 12:00:00 on 5th Oct 2024
  } else {
    Serial.println("RTC is running, time has been set previously.");
  }

  // Print the current date and time
  printTime();
}

void loop() {
  // Delay to avoid flooding the serial output
  delay(1000);
  printTime();
}

void printTime() {
  DateTime now = rtc.now();
  
  // Print the current date and time in 24-hour format
  Serial.print(now.year(), DEC);
  Serial.print('/');
  Serial.print(now.month(), DEC);
  Serial.print('/');
  Serial.print(now.day(), DEC);
  Serial.print(" ");
  Serial.print(now.hour(), DEC);
  Serial.print(':');
  Serial.print(now.minute(), DEC);
  Serial.print(':');
  Serial.print(now.second(), DEC);
  Serial.println();
}
